nbformat: The Jupyter Notebook format
=====================================

Description
-----------

The Jupyter Notebook format

License
-------

BSD 3-Clause License

Upstream Contact
----------------

https://pypi.org/project/nbformat/

